const app = getApp();

Page({
  
  data: {
    //判断小程序的API，回调，参数，组件等是否在当前版本可用。
    canIUse: wx.canIUse('button.open-type.getUserInfo'),
    scope: 'userinfo'
  },

  /**
   * 微信授权回调（用户信息）
   */
  bindGetUserInfo: function (e) {
    if (e.detail.userInfo) {
      this.wxLogin();
    } else {
      //TODO 用户拒绝了授权
    }
  },

  /**
   * 微信授权回调（手机号）
   */
  getPhoneNumber: function (e) {
    if (e.detail.encryptedData){
      this.bindMobile(e.detail);
    } else {
      //TODO 用户拒绝了授权
    }
  },

  /**
   * 查看是否授权，须在登录后调用
   */
  checkAuth: function(){
    var that = this;
    wx.getSetting({
      //是否带上登录态信息, true 返回的数据会包含 encryptedData, iv 等敏感信息
      withCredentials: true,
      success(res) {
        if (res.authSetting['scope.userInfo']) {
          wx.getUserInfo({
            success: function (res) {
              that.updateUserInfo(res);
            }
          })
        }
      }
    })
  },

  /**
   * 微信登录
   */
  wxLogin: function(){
    var that = this;
    wx.login({
      success: function (res) {
        if (res.code) {
          app.request("passport.applet.bind",{
             code: res.code 
          },{
            success: function (data, res) {
              that.checkAuth();
              that.setData({
                scope: 'phonenumber'
              });
            }
          })
        }
      }
    })
  },

  /**
   * 更新用户信息
   */
  updateUserInfo: function (wxObj){
    var that = this;
    var userInfo = wxObj.userInfo;
    var loginInfo = app.getLoginInfo();
    app.request('passport.applet.update',{
        nickname: userInfo.nickName,
        avatarurl: userInfo.avatarUrl,
        iv: wxObj.iv,
        encryptedData: wxObj.encryptedData,
        vid: loginInfo.vid,
        uid: loginInfo.uid,
        signature: loginInfo.signature
      } ,{
        success: function(data, res){
          //TODO 更新成功~
        }
    });
  },

  /**
   * 绑定手机号
   */
  bindMobile: function(wxObj){
    var that = this;
    var loginInfo = app.getLoginInfo();
    app.request('passport.applet.mobile', {
      iv: wxObj.iv,
      encryptedData: wxObj.encryptedData,
      vid: loginInfo.vid,
      uid: loginInfo.uid,
      signature: loginInfo.signature
    }, {
        success: function (data, res) {
          //TODO 更新成功~
          app.goBack();
        }
      });
  }

})